/** \file
 * \brief Remove overlaps function
 */
/*
 * Authors:
 *   Tim Dwyer <tgdwyer@gmail.com>
 *
 * Copyright (C) 2005 Authors
 *
 * Released under GNU LGPL.  Read the file 'COPYING' for more information.
 */

#ifndef SEEN_REMOVEOVERLAP_H
#define SEEN_REMOVEOVERLAP_H

#include <glib.h>

void removeoverlap(GSList const *items, double xGap, double yGap);

#endif // SEEN_REMOVEOVERLAP_H
